==> ficus-0.2.0157.tgz: ficus/pages/scaffold/ListScaffoldForeperson.php <==
<?php 
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
/*
 * Copyright 2004-2007 Project Guarana Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * @package ficus.pages.scaffold
 */
/**
 * @file ListScaffold.php
 * @brief table manager page
 * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
 * @version $Id: ListScaffoldForeperson.php 2 2007-07-11 10:37:48Z ishitoya $
 */

require_once("ficus/pages/AbstractPage.php");
require_once("ficus/config/Registry.php");
require_once("ficus/db/s2dao/models/serializer/S2DaoS2DaoArrayEntityDeserializer.php");
require_once("common/AbstractPage.php");

/**
 * @class Ficus_ListScaffold
 */
class Ficus_ListScaffold extends Ficus_AbstractScaffold
    /**
     * organize scaffold
     */
    public function onOrganize($request){
        $dto = $this->getPagerDto($args);
        $helper = new S2Dao_PagerViewHelper($dto);
        $entities = $this->dao->getWithCondition($dto);

        $container = $this->getContainer($entities);
        $organizer = $this->getListOrganizer();
        $organizer->setItemTemplate("itemWithMenu");
        $organizer->setRowTemplate("rowWithMenu");
        $organizer->setHeaderTemplate("headerWithMenu");
        $organizer->setEntityTemplate("table");
        $container->addOrganizers($organizer);

        $this->assignReference("container", $container);
        $this->assignReference("entities", $entities);
        $this->assignReference("helper", $helper);
    }
}    
?>

==> ficus-0.2.0161.tgz: ficus/pages/scaffold/ListScaffoldForeperson.php <==
<?php 
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
/*
 * Copyright 2004-2007 Project Guarana Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * @package ficus.pages.scaffold
 */
/**
 * @file ListScaffoldForeperson.php
 * @brief table manager page
 * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
 * @version $Id: ListScaffoldForeperson.php 14 2007-07-18 14:55:12Z ishitoya $
 */

require_once("ficus/pages/AbstractPage.php");
require_once("ficus/config/Registry.php");
require_once("ficus/db/s2dao/models/serializer/S2DaoArrayEntityDeserializer.php");
require_once("common/AbstractPage.php");

/**
 * @class Ficus_ListScaffoldForeperson
 */
class Ficus_ListScaffoldForeperson extends Ficus_AbstractScaffoldForeperson{
    /**
     * do default
     */
    public function doDefault(){
        $dto = $this->mediator->daoManager()->getPagerDto($args);
        $helper = new S2Dao_PagerViewHelper($dto);
        $entities =
            $this->mediator->daoManager()->dao()->getWithCondition($dto);

        $container = $this->mediator->getContainer($entities);
        $organizer =
            $this->mediator->organizerFactory()->createListOrganizer();
        $organizer->setItemTemplate("itemWithMenu");
        $organizer->setRowTemplate("rowWithMenu");
        $organizer->setHeaderTemplate("headerWithMenu");
        $organizer->setEntityTemplate("table");
        $container->addOrganizers($organizer);

        $this->mediator->smarty()->assign(self::KEY_HELPER, $helper);

        return $container->build();
    }
}
?>
